@@ -24,17 +24,17 @@ class ConfigHelper:
     def load(self):
         # Opens the configuration file and parse it to a JSON object
         try:
-            with open(self.config_path, 'r') as f:
-                config_raw = f.read()
+            with open(self.config_path, 'r') as config_file:
+                config_raw = config_file.read()
                 self._whole_config = json.loads(config_raw)
         except IOError:
             raise ValueError('No config found!')
 
     def _save(self):
         # Saves the JSON object back to file
-        with open(self.config_path, 'w+', encoding='utf-8') as f:
+        with open(self.config_path, 'w+', encoding='utf-8') as config_file:
             config_formatted = json.dumps(self._whole_config, indent=4)
-            f.write(config_formatted)
+            config_file.write(config_formatted)
 
     def get_property(self, key: str) -> any:
         # returns a property if configured
