@@ -19,9 +19,16 @@ class PathTools:
         Returns:
             str: The filtered string, that can be used as a filename.
         """
+
+        if name is None:
+            return None
+
         # Moodle saves the title of a section in HTML-Format,
         # so we need to unescape the string
-        name = html.unescape(name)
+        try:
+            name = html.unescape(name)
+        except Exception:
+            pass
 
         # Forward and Backward Slashes are not good for filenames
         for char in PathTools.filename_character_map:
@@ -57,7 +64,7 @@ class PathTools:
         @param file_path: The additional path of a file (subdirectory).
         @return: A path where the file should be saved.
         """
-        path = (
+        path = str(
             Path(storage_path)
             / PathTools.to_valid_name(course_fullname)
             / PathTools.to_valid_name(file_section_name)
@@ -77,7 +84,7 @@ class PathTools:
         @param file_path: The additional path of a file (subdirectory).
         @return: A path where the file should be saved.
         """
-        path = (
+        path = str(
             Path(storage_path)
             / storage_path
             / PathTools.to_valid_name(course_fullname)
@@ -95,5 +102,5 @@ class PathTools:
         @param file_path: The additional path of a file (subdirectory).
         @return: A path where the file should be saved.
         """
-        path = Path(storage_path) / storage_path / PathTools.to_valid_name(course_fullname) / file_path.strip('/')
+        path = str(Path(storage_path) / storage_path / PathTools.to_valid_name(course_fullname) / file_path.strip('/'))
         return path
