@@ -6,6 +6,9 @@ import sys
 import logging
 import argparse
 import traceback
+
+from shutil import which
+
 import sentry_sdk
 
 import moodle_dl.utils.process_lock as process_lock
@@ -19,9 +22,9 @@ except ImportError:
     pass
 
 from logging.handlers import RotatingFileHandler
-
 from moodle_dl.utils import cutie
 from moodle_dl.utils.logger import Log
+from moodle_dl.version import __version__
 from moodle_dl.download_service.path_tools import PathTools
 from moodle_dl.config_service.config_helper import ConfigHelper
 from moodle_dl.config_service.config_service import ConfigService
@@ -174,7 +177,7 @@ def run_change_notification_telegram(storage_path):
     Log.success('Telegram Configuration successfully updated!')
 
 
-def run_main(storage_path, skip_cert_verify=False, without_downloading_files=False, log_responses=False):
+def run_main(storage_path, verbose=False, skip_cert_verify=False, without_downloading_files=False, log_responses=False):
 
     log_formatter = logging.Formatter('%(asctime)s  %(levelname)s  {%(module)s}  %(message)s', '%Y-%m-%d %H:%M:%S')
     log_file = os.path.join(storage_path, 'MoodleDownloader.log')
@@ -183,25 +186,39 @@ def run_main(storage_path, skip_cert_verify=False, without_downloading_files=Fal
     )
 
     log_handler.setFormatter(log_formatter)
-    log_handler.setLevel(logging.DEBUG)
+    if verbose:
+        log_handler.setLevel(logging.DEBUG)
+    else:
+        log_handler.setLevel(logging.INFO)
 
     app_log = logging.getLogger()
-    app_log.setLevel(logging.DEBUG)
+    if verbose:
+        app_log.setLevel(logging.DEBUG)
+    else:
+        app_log.setLevel(logging.INFO)
     app_log.addHandler(log_handler)
 
-    logging.info('--- main started ---------------------')
+    logging.info('--- moodle-dl started ---------------------')
     Log.info('Moodle Downloader starting...')
+    if verbose:
+        logging.debug('moodle-dl version: %s', __version__)
+        logging.debug('python version: %s', ".".join(map(str, sys.version_info[:3])))
+        ffmpeg_available = which('ffmpeg') is not None
+        logging.debug('Is ffmpeg available: %s', ffmpeg_available)
+
     if IS_DEBUG:
         logging.info('Debug-Mode detected. Errors will not be logged but instead re-risen.')
         app_log.addHandler(ReRaiseOnError())
 
     try:
-        logging.debug('Loading config...')
-        Log.debug('Loading config...')
+        msg_load_config = 'Loading config...'
+        logging.debug(msg_load_config)
+        Log.debug(msg_load_config)
+
         config = ConfigHelper(storage_path)
         config.load()
     except BaseException as e:
-        logging.error('Error while trying to load the Configuration! {} Exiting...'.format(e), extra={'exception': e})
+        logging.error('Error while trying to load the Configuration! %s Exiting...', e, extra={'exception': e})
         Log.error('Error while trying to load the Configuration!')
         sys.exit(-1)
 
@@ -225,12 +242,23 @@ def run_main(storage_path, skip_cert_verify=False, without_downloading_files=Fal
 
         moodle = MoodleService(config, storage_path, skip_cert_verify, log_responses)
 
-        logging.debug('Checking for changes for the configured Moodle-Account....')
-        Log.debug('Checking for changes for the configured Moodle-Account...')
+        msg_checking_for_changes = 'Checking for changes for the configured Moodle-Account....'
+        logging.debug(msg_checking_for_changes)
+        Log.debug(msg_checking_for_changes)
         changed_courses = moodle.fetch_state()
 
-        logging.debug('Start downloading changed files...')
-        Log.debug('Start downloading changed files...')
+        if log_responses:
+            msg_responses_logged = (
+                "All JSON-responses from Moodle have been written to the responses.log file. Exiting..."
+            )
+            logging.debug(msg_responses_logged)
+            Log.success(msg_responses_logged)
+            process_lock.unlock(storage_path)
+            return
+
+        msg_start_downloading = 'Start downloading changed files...'
+        logging.debug(msg_start_downloading)
+        Log.debug(msg_start_downloading)
 
         if without_downloading_files:
             downloader = FakeDownloadService(changed_courses, moodle, storage_path)
@@ -248,8 +276,9 @@ def run_main(storage_path, skip_cert_verify=False, without_downloading_files=Fal
             moodle.recorder.notified(changed_courses_to_notify)
 
         else:
-            logging.info('No changes found for the configured Moodle-Account.')
-            Log.warning('No changes found for the configured Moodle-Account.')
+            msg_no_changes = 'No changes found for the configured Moodle-Account.'
+            logging.info(msg_no_changes)
+            Log.warning(msg_no_changes)
 
         process_lock.unlock(storage_path)
 
@@ -298,6 +327,11 @@ def get_parser():
         description=('Moodle Downloader 2 helps you download all the course files  of your Moodle account.')
     )
     group = parser.add_mutually_exclusive_group()
+
+    group.add_argument(
+        '--version', action='version', version='moodle-dl ' + __version__, help='Print program version and exit'
+    )
+
     group.add_argument(
         '-i',
         '--init',
@@ -387,6 +421,14 @@ def get_parser():
         ),
     )
 
+    parser.add_argument(
+        '-v',
+        '--verbose',
+        default=False,
+        action='store_true',
+        help='Print various debugging information',
+    )
+
     parser.add_argument(
         '--skip-cert-verify',
         default=False,
@@ -437,6 +479,7 @@ def main(args=None):
     args = parser.parse_args(args)
 
     use_sso = args.sso
+    verbose = args.verbose
     storage_path = args.path
     skip_cert_verify = args.skip_cert_verify
     without_downloading_files = args.without_downloading_files
@@ -456,4 +499,4 @@ def main(args=None):
     elif args.manage_database:
         run_manage_database(storage_path)
     else:
-        run_main(storage_path, skip_cert_verify, without_downloading_files, log_responses)
+        run_main(storage_path, verbose, skip_cert_verify, without_downloading_files, log_responses)
